import './LoginPage.css'
import {Link, useNavigate} from "react-router-dom";
import React, {useState} from "react";
import {loginAPI, signUpProfessorPagePath, signUpStudentPagePath, welcomePagePath} from "../utils.ts";
import {LoginProps} from "../types.ts";

export default function LoginPage({onLogin}: LoginProps) {

    const [email, setEmail] = useState('');
    const [password, setPassword] = useState('');
    const navigate = useNavigate();

    const handleEmailChange = (e: React.ChangeEvent<HTMLInputElement>) => {
        setEmail(e.target.value);
    }

    const handlePasswordChange = (e: React.ChangeEvent<HTMLInputElement>) => {
        setPassword(e.target.value);
    }

    const handleSubmit = (e: React.FormEvent<HTMLFormElement>) => {
        e.preventDefault();

        fetch(`${loginAPI}`, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Accept': 'application/json',  // Ensure the client accepts JSON response
            },
            body: JSON.stringify({username: email, password: password}),
        })
            .then(response => {
                console.log("Response:", response);
                if (!response.ok) {
                    throw new Error('Login failed');
                }
                const authHeader = response.headers.get('Authorization');
                if (authHeader) {
                    const token = authHeader.replace('Bearer ', '');
                    sessionStorage.setItem('token', token);
                    onLogin(token);
                } else {
                    console.log("Authorization header not found");
                }
                return response.json();
            })
            .then(data => {
                if (data.success) {
                    console.log('Login successful');
                    navigate(`${welcomePagePath}`);   // We can change this
                } else {
                    alert('Login failed: ' + data.message);
                }
            })
            .catch((error) => {
                console.error('Error:', error);
                alert('Login failed: ' + error.message);
            });
    };

    return (
        <div className='login-page center-content'>
            <section className='login-form'>
                <h2>Login</h2>
                <form onSubmit={handleSubmit}>
                    <label htmlFor='email'>Email:</label>
                    <input type='email' id='email' name='email' required
                           value={email}
                           onChange={handleEmailChange}/>
                    <label htmlFor='password'>Password:</label>
                    <input type='password' id='password' name='password' required
                           value={password}
                           onChange={handlePasswordChange}/>
                    <div className='remember-me'>
                        <input type='checkbox' id='remember-me' name='remember-me'/>
                        <label htmlFor='remember-me'>Remember Me?</label>
                    </div>
                    <button className="primary-button" type='submit'>LOGIN</button>
                </form>
                <div className="no-account">
                    <p>Don't have an account?</p>
                    <Link to={signUpStudentPagePath}>Student Sign Up</Link>
                    <Link to={signUpProfessorPagePath}>Professor Sign Up</Link>
                </div>
            </section>
        </div>
    );
}
