import "./SignUpPage.css"
import {Link} from "react-router-dom";
import {loginPagePath, signUpStudentPagePath} from "../utils.ts";
import {useState} from "react";

export default function SignUpProfessorPage() {

    const [isPI, setIsPI] = useState(false);

    const handlePIChange = (e: React.ChangeEvent<HTMLInputElement>) => {
        setIsPI(e.target.value === 'pi-yes');
    }

    const [addLab, setAddLab] = useState(false);

    const handleLabChange = (e: React.ChangeEvent<HTMLInputElement>) => {
        setAddLab(e.target.checked
        );
    }

    return (
        <div className='signup-professor-page center-content'>
            <section className='signup-form'>
                <h2>Professor Sign Up</h2>
                <form>
                    <label htmlFor='first-name'>First Name:</label>
                    <input type='text' id='first-name' name='first-name' required/>
                    <label htmlFor='last-name'>Last Name:</label>
                    <input type='text' id='last-name' name='last-name' required/>
                    <label htmlFor='email'>VT Email:</label>
                    <input type='email' id='email' name='email' required/>
                    <label htmlFor='password'>Password:</label>
                    <input type='password' id='password' name='password' required/>
                    <label htmlFor='confirm-password'>Confirm Password:</label>
                    <input type='password' id='confirm-password' name='confirm-password' required/>

                    {/*Are you a Principal Investigator? radio buttons yes or no*/}
                    <div className='professor-type'>
                        <label>Are you a Principal Investigator?</label>
                        <div>
                            <input type='radio' id='pi-yes' name='professor-type' value='pi-yes'
                                   onChange={handlePIChange}/>
                            <label htmlFor='pi-yes'>Yes</label>
                        </div>
                        <div>
                            <input type='radio' id='pi-no' name='professor-type' value='pi-no'
                                   onChange={handlePIChange}/>
                            <label htmlFor='pi-no'>No</label>
                        </div>
                    </div>

                    {isPI && (
                        <div className='research-lab-addition'>
                            <input type='checkbox' id='research-lab-checkbox' name='research-lab-checkbox'
                                   onChange={handleLabChange}/>
                            <label htmlFor='research-lab-checkbox'>Add Research Lab?</label>
                        </div>
                    )}
                    {isPI && addLab && (
                        <>
                            <label htmlFor='research-lab-name'>Research Lab Name:</label>
                            <input type='text' id='research-lab-name' name='research-lab-name' required/>

                            <label htmlFor='research-lab-website'>Research Lab Website URL:</label>
                            <input type='url' id='research-lab-website' name='research-lab-website' required/>

                            <label htmlFor='research-lab-college'>Research Lab College:</label>
                            <select id='research-lab-college' name='research-lab-college' required>
                                <option value='agr'>College of Agriculture and Life Sciences</option>
                                <option value='arc'>College of Architecture, Arts, and Design</option>
                                <option value='bus'>Pamplin College of Business</option>
                                <option value='eng'>College of Engineering</option>
                                <option value='lib'>College of Liberal Arts and Human Sciences</option>
                                <option value='nat'>College of Natural Resources and Environment</option>
                                <option value='sci'>College of Science</option>
                            </select>

                            <label htmlFor='research-lab-description'>Research Lab Description:</label>
                            <textarea id='research-lab-description' name='research-lab-description' required/>
                        </>
                    )}

                    <button className="primary-button" type='submit'>SIGN UP</button>
                </form>
                <div className="have-account">
                    <p>Already have an account?</p>
                    <Link to={loginPagePath}>Login</Link>
                    <p>Not a Professor?</p>
                    <Link to={signUpStudentPagePath}>Student Sign Up</Link>
                </div>
            </section>
        </div>
    );
}