import {Link} from "react-router-dom";
import "./SignUpPage.css"
import {loginPagePath, signUpProfessorPagePath} from "../utils.ts";
import {useMajorContext} from "../contexts/MajorContext.tsx";

export default function SignUpStudentPage() {

    const {majors} = useMajorContext();

    return (
        <div className='signup-student-page center-content'>
            <section className='signup-form'>
                <h2>Student Sign Up</h2>
                <form>
                    <label htmlFor='first-name'>First Name:</label>
                    <input type='text' id='first-name' name='first-name' required/>
                    <label htmlFor='last-name'>Last Name:</label>
                    <input type='text' id='last-name' name='last-name' required/>
                    <label htmlFor='email'>VT Email:</label>
                    <input type='email' id='email' name='email' required/>
                    <label htmlFor='password'>Password:</label>
                    <input type='password' id='password' name='password' required/>
                    <label htmlFor='confirm-password'>Confirm Password:</label>
                    <input type='password' id='confirm-password' name='confirm-password' required/>

                    <label htmlFor='student-type'>Student Type:</label>
                    <div className='radio-buttons'>
                        <label htmlFor='undergraduate'><input type='radio' id='undergraduate' name='student-type'
                                                              value='undergraduate' required/>Undergraduate</label>
                        <label htmlFor='graduate-masters'><input type='radio' id='graduate-masters' name='student-type'
                                                                 value='graduate-masters' required/>Graduate (Master's)</label>
                        <label htmlFor='graduate-phd'><input type='radio' id='graduate-phd' name='student-type'
                                                             value='graduate-phd' required/>Graduate (PhD)</label>
                    </div>

                    <label htmlFor='major'>Major:</label>
                    <select id='major' name='major' required>
                        {majors.map((major) => (
                            <option key={major.id} value={major.id}>
                                {major.name}
                            </option>
                        ))}
                    </select>

                    <label htmlFor='situation'>Select the boxes that best describe you:</label>
                    <div className='checkboxes'>
                        <label htmlFor='seeking-volunteer'><input type='checkbox' id='seeking-volunteer'
                                                                  name='seeking-volunteer'
                                                                  value='seeking-volunteer'/> Seeking Volunteer
                            Opportunities</label>
                        <label htmlFor='seeking-credit'><input type='checkbox' id='seeking-credit' name='seeking-credit'
                                                               value='seeking-credit'/> Seeking Credit
                            Opportunities</label>
                        <label htmlFor='seeking-paid'><input type='checkbox' id='seeking-paid' name='seeking-paid'
                                                             value='seeking-paid'/> Seeking Paid
                            Opportunities</label>
                        <label htmlFor='current-volunteer'><input type='checkbox' id='current-volunteer'
                                                                  name='current-volunteer'
                                                                  value='current-volunteer'/> Currently a
                            Volunteer</label>
                        <label htmlFor='current-credit'><input type='checkbox' id='current-credit' name='current-credit'
                                                               value='current-credit'/> Currently Receiving
                            Credit</label>
                        <label htmlFor='current-paid'><input type='checkbox' id='current-paid' name='current-paid'
                                                             value='current-paid'/> Currently Paid</label>
                        <label htmlFor='other'><input type='checkbox' id='other' name='other'
                                                      value='other'/> Other</label>
                    </div>


                    <button className="primary-button" type='submit'>SIGN UP</button>
                </form>

                <div className="have-account">
                    <p>Already have an account?</p>
                    <Link to={loginPagePath}>Login</Link>
                    <p>Not a Student?</p>
                    <Link to={signUpProfessorPagePath}>Professor Sign Up</Link>
                </div>
            </section>
        </div>
    );
}