import './WelcomePage.css'
import {Link} from "react-router-dom";
import {
    discussionPagePath,
    labsPagePath,
    openingsPagePath,
    signUpProfessorPagePath,
    signUpStudentPagePath
} from "../utils.ts";
import {WelcomeProps} from "../types.ts";

export default function WelcomePage({isLoggedIn}: WelcomeProps) {
    return (
        <div className="welcome-page center-content">

            {isLoggedIn ? (
                <>
                    <h1 className="logged-in-content">START EXPLORING</h1>
                </>
            ) : (
                <>
                    <section className="welcome-students">
                        <h2>Welcome Students</h2>
                        <p>As a student, you can easily explore and filter through all the <Link to={labsPagePath}>Research
                            Labs</Link> at
                            Virginia Tech. Each lab's profile includes essential details such as the lab name, the
                            principal
                            investigator (PI), and a link to their external website. Additionally, you can search
                            for <Link
                                to={openingsPagePath}>Openings</Link> and apply for volunteer or paid positions in
                            various research labs. Join
                            our <Link to={discussionPagePath}>Discussion Forum</Link> to engage with fellow students,
                            share insights about
                            research, and subscribe to feeds based on department, topic, or specific labs.</p>
                        <Link to={signUpStudentPagePath}>
                            <button className="call-to-action-button">STUDENT SIGN UP!</button>
                        </Link>
                    </section>
                    <section className="welcome-professors">
                        <h2>Welcome Professors</h2>
                        <p>As a professor, you can showcase your <Link to={labsPagePath}>Research Lab</Link> to the
                            vibrant Virginia Tech
                            community. Create a comprehensive profile that includes your lab's name, your role as the
                            principal
                            investigator (PI), and a link to your external website. Post <Link
                                to={openingsPagePath}>Openings</Link> for
                            volunteer and paid positions to attract enthusiastic and qualified students. Engage with
                            students
                            and colleagues in our <Link to={discussionPagePath}>Discussion Forum</Link>, where you can
                            share insights, foster
                            collaborations, and stay updated on the latest research topics and departmental news.</p>
                        <Link to={signUpProfessorPagePath}>
                            <button className="call-to-action-button">PROFESSOR SIGN UP!</button>
                        </Link>
                    </section>
                </>
            )}
        </div>
    );
}